Crate deno_websocket

Crate deno_websocket 

Structs

CreateResponse
ServerWebSocket
To avoid locks, we keep as much as we can inside of Cells.
WsCancelResource
deno_websocket
An extension for use with the Deno JS runtime. To use it, provide it as an argument when instantiating your runtime:

Enums

HandshakeError
MessageKind
WebsocketError

Functions

op_ws_check_permission_and_cancel_handle
op_ws_close
op_ws_create
op_ws_get_buffer
op_ws_get_buffer_as_string
op_ws_get_buffered_amount
op_ws_get_error
op_ws_next_event
op_ws_send_binary
op_ws_send_binary_ab
op_ws_send_binary_async
op_ws_send_ping
op_ws_send_text
op_ws_send_text_async
ws_create_server_stream
ws_create_server_stream_with_guard
Like ws_create_server_stream but lets the embedder attach an opaque lifetime guard that lives as long as the underlying ServerWebSocket resource. The embedder can also recover an Rc<ServerWebSocket> for the new resource through the returned ResourceId in order to drive a server-initiated shutdown later via ServerWebSocket::server_shutdown.